dx.wts takes a ps object or a set of propensity scores and
computes diagnostics assessing covariates balance.dx.wts(x,
data,
estimand,
vars=NULL,
treat.var,
x.as.weights=TRUE,
sampw=NULL,
perm.test.iters=0)x can also be a data frame, matrix, or vector of
propensity scores if x.as.weights=FALSEdata on
which to assess balancedata
contains the 0/1 treatment group indicatorTRUE or FALSE indicating whether x
specifies propensity score weights or propensity scores.
Ignored if x is a ps objectx is a ps object then the
sampling weights should have been passed to ps and
not specified here. dx.wts will issue a warniperm.test.iters=0
then the function returns an analytic approximation to the p-value. This
argument is ignoreddx.wtsdx.wtsps contains an example of the
use of dx.wts